@@ -93,6 +93,13 @@ def padRect(image, box, padding):
     return (int(x0), int(y0), int(x1), int(y1))
 
 
+def isNearbyPoint(target, radius, point):
+    x0, y0 = target
+    x1, y1 = point
+    length = ((x1-x0)**2+(y1-y0)**2)**0.5
+    return length < radius
+
+
 count = 0
 # 精确计算目标区域
 
@@ -107,7 +114,7 @@ def calcRect(image, box, padding=10, areaThreshold=10):
     # 放到目标区域
     x0, y0, x1, y1 = padRect(image, box, pad)
     img = image[y0:y1, x0:x1]
-    cv2.imshow('part'+str(count), img)
+    # cv2.imshow('part'+str(count), img)
     # 灰度
     img = cv2.cvtColor(img, cv2.COLOR_RGB2GRAY)
 
@@ -116,23 +123,53 @@ def calcRect(image, box, padding=10, areaThreshold=10):
     img = cv2.GaussianBlur(img, (3, 3), 0)
 
     # Canny提取边缘
-    processed = cv2.Canny(img, 100, 200, 1)
+    processed = cv2.Canny(img, 100, 300, 1)
     cv2.imshow('Canny'+str(count), processed)
     # 寻找轮廓
     contours, hierarchy = cv2.findContours(
         processed, cv2.RETR_EXTERNAL, cv2.CHAIN_APPROX_SIMPLE)
 
-    print('findContours'+str(count)+':'+str(len(contours)))
+    # print('findContours'+str(count)+':'+str(len(contours)))
 
     temp = cv2.drawContours(img.copy(), contours, -1, (0, 0, 255), 1)
 
-    cv2.imshow('drawContours'+str(count), temp)
+    # cv2.imshow('drawContours'+str(count), temp)
 
     if(len(contours) <= 0):
         return None
 
     rects = [cv2.boundingRect(cnt) for cnt in contours]
 
+    drrects=map(lambda item:[0,item[0]+item[2]/2,item[1]+item[3]/2,item[2],item[3]] ,rects)
+    img1 = drawRect(img, drrects)
+    showImg("rectx"+str(count), img1)
+
+    points = list()
+    for rect in rects:
+        points.append((rect[0], rect[1]))
+        points.append((rect[0]+rect[2], rect[1]+rect[3]))
+        points.append((rect[0], rect[1]+rect[3]))
+        points.append((rect[0]+rect[2], rect[1]))
+
+    # 四个顶点
+    point4s = [(0, 0), (x1-x0, 0), (0, y1-y0), (x1-x0, y1-y0)]
+
+    
+    tarPoints=[]
+    radius=20
+    for point in points:
+        for p in point4s:
+            if(isNearbyPoint(p,radius,point)):
+                tarPoints.append(point)
+
+    rect = cv2.boundingRect(np.array(tarPoints))
+
+    drrects=map(lambda item:[0,item[0]+item[2]/2,item[1]+item[3]/2,item[2],item[3]] ,[rect])
+    img1 = drawRect(img, drrects)
+    showImg("rect"+str(count), img1)
+
+    rects = [rect]
+
     # # 根据面积过滤，筛选大面积的框
     rects = list(filter(lambda rect: rect[2]*rect[3] > areaThreshold, rects))
 
@@ -179,7 +216,7 @@ def calcRectByImage(image, boxs=[], padding=10, areaThreshold=900):
         if(result != None):
             x, y, w, h = result[0]-padding, result[1] - \
                 padding, result[2], result[3]
-            if((w*h)/(width*height) > 0.8):
+            if((w*h)/(width*height) > 0.5):
                 x = 0 if(x < 0) else x
                 y = 0 if(y < 0) else y
                 w = imgWidth-x if(x+w > imgWidth) else w
@@ -202,43 +239,49 @@ def drawRect(image, rects=[]):
     boxs = []
     for rect in rects:
         pass
-        p0, p1, n = (rect[1]+pad, rect[2] +pad), (rect[3], rect[4]), 0
+        p0, p1, n = (rect[1]+pad, rect[2] + pad), (rect[3], rect[4]), 0
         box = np.int0(cv2.boxPoints((p0, p1, n)))
         boxs.append(box)
 
-    temp = cv2.drawContours(img.copy(), boxs, -1, (0, 0, 255), 1)
+    temp = cv2.drawContours(img.copy(), boxs, -1, (0, 0, 255), 2)
 
     return temp
 
 
 def rectToBox(rects=[]):
-    boxs = [ [rect[0],rect[1]-rect[3]/2,rect[2]-rect[4]/2,rect[3],rect[4] ] for rect in rects]
+    boxs = [[rect[0], rect[1]-rect[3]/2, rect[2] -
+             rect[4]/2, rect[3], rect[4]] for rect in rects]
     return boxs
 
+
 def boxToRect(boxs=[]):
-    rects = [ [box[0],box[1]+box[3]/2,box[2]+box[4]/2,box[3],box[4] ] for box in boxs]
+    rects = [[box[0], box[1]+box[3]/2, box[2]+box[4]/2, box[3], box[4]]
+             for box in boxs]
     return rects
 
+
 def showImg(name, img):
-    img = cv2.resize(img, (int(img.shape[1]/2),int(img.shape[0]/2)))
+    img = cv2.resize(img, (int(img.shape[1]/2), int(img.shape[0]/2)))
     borderType = cv2.BORDER_CONSTANT
     value = [255, 255, 255]
-    img = cv2.copyMakeBorder(img, 20, 20, 20,20, borderType, None, value)
+    img = cv2.copyMakeBorder(img, 20, 20, 20, 20, borderType, None, value)
     cv2.imshow(name, img)
 
 
-img = cv2.imread("./image/page277.jpg", 1)
+img = cv2.imread("./image/bjnsh_.png", 1)
 
 # showImg("img", img)
 
-rects =[[1, 321.0, 256.0, 130.0, 24.0], [0, 323.0, 797.5, 576.0, 117.0], [1, 319.0, 484.0, 602.0, 418.0], [0, 323.0, 99.5, 644.0, 195.0]]
-rects = list(filter(lambda item: item[0] == 0, rects))
+rects = [[1, 709.0, 641.5, 274.0, 29.0], [1, 841.5, 33.5, 93.0, 35.0], [1, 363.0, 642.0, 250.0, 26.0], [0, 724.5, 693.0, 117.0, 42.0], [0, 390.0, 689.5, 126.0, 39.0], [1, 1066.5, 34.5, 89.0, 35.0], [1, 986.0, 644.0, 146.0, 22.0], [1, 1175.0, 34.0, 94.0, 34.0], [0, 1065.0, 689.5, 124.0, 37.0], [1, 727.5, 34.0, 91.0, 34.0], [1, 952.5, 33.5, 95.0, 35.0], [2, 633.5, 38.0, 73.0, 68.0], [0, 353.5, 37.0, 319.0, 62.0], [0, 723.0, 557.5, 338.0,
+                                                                                                                                                                                                                                                                                                                                                                                                                                135.0], [0, 383.5, 561.5, 321.0, 129.0], [0, 1070.0, 563.5, 324.0, 133.0], [0, 721.0, 254.5, 1442.0, 375.0]]
+
+rects = list(filter(lambda item: item[0] == 0 or item[0] == 2 , rects))
 
 img1 = drawRect(img, rects)
 showImg("source", img1)
 
 boxs = rectToBox(rects)
-boxs = calcRectByImage(img, boxs, 20, 900)
+boxs = calcRectByImage(img, boxs, 5, 900)
 # print('boxs1')
 # print(boxs)
 
