@@ -1,6 +1,8 @@
 import cv2
 import numpy as np
 
+AREA_RATE = 0.7
+
 # 填充目标区域padding像素
 def padRect(image, box, padding):
     height, width, num = image.shape
@@ -17,12 +19,19 @@ def padRect(image, box, padding):
     return (int(x0), int(y0), int(x1), int(y1))
 
 
+def isNearbyPoint(target, radius, point):
+    x0, y0 = target
+    x1, y1 = point
+    length = ((x1-x0)**2+(y1-y0)**2)**0.5
+    return length < radius
+
+
 # 精确计算目标区域
-def calcRect(image, box, padding=30, areaThreshold=10):
+def calcRect(image, box, padding=5, areaThreshold=900):
 
     height, width, chanel = image.shape
 
-    pad = min(box[2], box[3])*0.1
+    pad = max(box[2], box[3])*0.1
     pad = padding if pad > padding else pad
     # 放到目标区域
     x0, y0, x1, y1 = padRect(image, box, pad)
@@ -36,7 +45,7 @@ def calcRect(image, box, padding=30, areaThreshold=10):
     img = cv2.GaussianBlur(img, (3, 3), 0)
 
     # Canny提取边缘
-    processed = cv2.Canny(img, 50, 150, 1)
+    processed = cv2.Canny(img, 50, 100, 1)
 
     # 寻找轮廓
     contours, hierarchy = cv2.findContours(
@@ -47,22 +56,34 @@ def calcRect(image, box, padding=30, areaThreshold=10):
 
     rects = [cv2.boundingRect(cnt) for cnt in contours]
 
-    # 根据面积过滤，筛选大面积的框
-    rects = list(filter(lambda rect: rect[2]*rect[3] > areaThreshold, rects))
+    points = list()
+    for rect in rects:
+        points.append((rect[0], rect[1]))
+        points.append((rect[0]+rect[2], rect[1]+rect[3]))
+        # points.append((rect[0], rect[1]+rect[3]))
+        # points.append((rect[0]+rect[2], rect[1]))
 
-    if(len(rects) <= 0):
-        return None
+    # # 四个顶点
+    # point4s = [(0, 0), (x1-x0, 0), (0, y1-y0), (x1-x0, y1-y0)]
 
-    # 坐标修正
-    rects = [[rect[0]+x0, rect[1]+y0, rect[2], rect[3]] for rect in rects]
+    # # 寻找离四个顶点最近的矩形点
+    # tarPoints=[]
+    # radius=(x1-x0)/3
+    # for point in points:
+    #     for p in point4s:
+    #         if(isNearbyPoint(p,radius,point)):
+    #             tarPoints.append(point)
 
-    # 获取最大的矩形
-    rects = max(rects, key=lambda rect: rect[2]*rect[3])
+    # if(len(tarPoints)>0):
+    #     rect = cv2.boundingRect(np.array(tarPoints))
+    # else:
+    #     rect = cv2.boundingRect(np.array(points))
 
-    return rects
+    rect = cv2.boundingRect(np.array(points))
+    return [rect[0]+x0, rect[1]+y0, rect[2], rect[3]]
 
 # 框校准，image 是图片的三维数组
-def calcRectByImage(image, boxs=[], padding=10, areaThreshold=900):
+def calcRectByImage(image, boxs=[], padding=5, areaThreshold=900):
     imgHeight, imgWidth, chanel = image.shape
     borderType = cv2.BORDER_CONSTANT
     value = [255, 255, 255]
@@ -77,9 +98,15 @@ def calcRectByImage(image, boxs=[], padding=10, areaThreshold=900):
         if(result != None):
             x, y, w, h = result[0]-padding, result[1] - \
                 padding, result[2], result[3]
-            if((w*h)/(width*height) > 0.7):
-                x = 0 if(x < 0) else x
-                y = 0 if(y < 0) else y
+            if((w*h)/(width*height) > AREA_RATE):
+                if(x < 0):
+                    w = w+x
+                    x = 0
+                # x = 0 if(x < 0) else x
+                if(y < 0):
+                    h = h+y
+                    y = 0
+                # y = 0 if(y < 0) else y
                 w = imgWidth-x if(x+w > imgWidth) else w
                 h = imgHeight-y if(y+h > imgHeight) else h
                 results.append([label, x, y, w, h])
@@ -91,12 +118,12 @@ def calcRectByImage(image, boxs=[], padding=10, areaThreshold=900):
     return results
 
 # 图片框校准,image 是二进制数组
-def calcRectByImageBytes(image, boxs=[], padding=20, areaThreshold=900):
+def calcRectByImageBytes(image, boxs=[], padding=5, areaThreshold=900):
     arr = np.asarray(bytearray(image), dtype="uint8")
     img = cv2.imdecode(arr, cv2.IMREAD_COLOR)
     return calcRectByImage(img, boxs, padding, areaThreshold)
 
 # 图片框校准,source 是图片文件路径
-def calcRectByImagePath(source, boxs=[], padding=20, areaThreshold=900):
+def calcRectByImagePath(source, boxs=[], padding=5, areaThreshold=900):
     img = img0 = cv2.imread(source)
     return calcRectByImage(img, boxs, padding, areaThreshold)
